@@ -11,7 +11,7 @@ use vars qw(@ISA $VERSION);
 
 @ISA     = qw(Net::FTP);
 
-$VERSION = '5.2';
+$VERSION = '5.30';
 
 # Preloaded methods go here.
 
@@ -24,7 +24,7 @@ sub new {
     (
      Host => 'ftp.microsoft.com',
      RemoteDir  => '/pub',
-     LocalDir  => '.',   # setup something for $ez->get
+#     LocalDir  => '.',   # setup something for $ez->get
      Type => 'I'
     );
 
@@ -47,6 +47,9 @@ sub new {
       open STDERR, ">&DUP";
   }
 
+  warn "Net::FTP::Common::VERSION = ", $Net::FTP::Common::VERSION  
+      if $self->{Debug} ;
+
 
   bless $new_self, $pkg;
 }
@@ -193,7 +196,41 @@ sub dir {
     foreach (@{$dir})
         {
 	    # $_ =~ m#([a-z-]*)\s*([0-9]*)\s*([0-9a-zA-Z]*)\s*([0-9a-zA-Z]*)\s*([0-9]*)\s*([A-Za-z]*)\s*([0-9]*)\s*([0-9A-Za-z:]*)\s*([A-Za-z0-9.-]*)#;
-	      $_ = m#([a-z-]*)\s*([0-9]*)\s*([0-9a-zA-Z]*)\s*([0-9a-zA-Z]*)\s*([0-9]*)\s*([A-Za-z]*)\s*([0-9]*)\s*([0-9A-Za-z:]*)\s*([\w*\W*\s*\S*]*)#;
+	  #$_ = m#([a-z-]*)\s*([0-9]*)\s*([0-9a-zA-Z]*)\s*([0-9a-zA-Z]*)\s*([0-9]*)\s*([A-Za-z]*)\s*([0-9]*)\s*([0-9A-Za-z:]*)\s*([\w*\W*\s*\S*]*)#;
+
+=for comment
+
+drwxr-xr-x    8 0        0            4096 Sep 27  2003 .
+drwxr-xr-x    8 0        0            4096 Sep 27  2003 ..
+drwxr-xr-x    3 0        0            4096 Sep 11  2003 .afs
+-rw-r--r--    1 0        0             809 Sep 26  2003 .banner
+----r-xr-x    1 0        0               0 Mar  4  2002 .notar
+-rw-r--r--    1 0        0             796 Sep 27  2003 README
+
+=cut
+
+	  warn "input-line: $_" if $self->{Debug} ;
+
+	  $_ =~ m!^
+	    ([\-FlrwxsStTdD]{10})  # directory and permissions
+	    \s+
+	    (\d+)                  # inode
+	    \s+
+	    (\w+)                  # 2nd number
+	    \s+
+	    (\w+)                  # 3rd number
+	    \s+
+	    (\d+)                  # file/dir size
+	    \s+
+	    (\w{3,4})         # month
+	    \s+
+	    (\d{1,2})         # day
+	    \s+
+	    (\d{1,2}:\d{2}|\d{4})           # year
+	    \s+
+		(.+) # filename
+		  $!x;
+
 
         my $perm = $1;
         my $inode = $2;
@@ -206,6 +243,19 @@ sub dir {
         my $name = $9;
         my $linkTarget;
 
+	  warn "
+        my $perm = $1;
+        my $inode = $2;
+        my $owner = $3;
+        my $group = $4;
+        my $size = $5;
+        my $month = $6;
+        my $day = $7;
+        my $yearOrTime = $8;
+        my $name = $9;
+        my $linkTarget;
+" if $self->{Debug} ;
+
         if ( $' =~ m#\s*->\s*([A-Za-z0-9.-/]*)# )       # it's a symlink
                 { $linkTarget = $1; }
 
@@ -219,6 +269,8 @@ sub dir {
         $HoH{$name}{yearOrTime} =  $yearOrTime;
         $HoH{$name}{linkTarget} = $linkTarget;
 
+	  warn "regexp-matches for ($name): ", Dumper(\$HoH{$name}) if $self->{Debug} ;
+
         }
   return(%HoH);
   }
@@ -235,9 +287,6 @@ sub mkdir {
     $ftp->mkdir($rd, $r);
 }
 
-# The Perl -e operator for files on a remote site. Even though the
-# REBOL exists? word works on local files as well as URL's, Perl's does 
-# not. Shame isn't it? :-)
 
 sub exists {
     my ($self,%cfg) = @_;
@@ -246,11 +295,24 @@ sub exists {
 
     my $rf = $self->GetCommon('RemoteFile');
 
-    warn sprintf "[checking @listing for [%s]]", $rf;
+   warn sprintf "[checking @listing for [%s]]", $rf if $self->{Debug} ;
 
     scalar grep { $_ eq $self->GetCommon('RemoteFile') } @listing;
 }
 
+sub delete {
+    my ($self,%cfg) = @_;
+
+    my $ftp = $self->prep(%cfg);
+    my $rf  = $self->GetCommon('RemoteFile');
+
+    
+    warn Dumper \%cfg;
+
+    $ftp->delete($rf);
+
+}
+
 sub grep {
 
     my ($self,%cfg) = @_;
@@ -276,10 +338,18 @@ sub connected {
     $connected;
 }
 
+sub quit {
+    my $self = shift; 
+
+    $self->connected and $self->GetCommon('FTPSession')->quit;
+
+}
+
+
 sub prepped {
     my $self = shift; 
     my $prepped = $self->GetCommon('FTPSession') and $self->connected;
-#    warn "prepped: $prepped";
+    #    warn "prepped: $prepped";
     $prepped;
 }
 
@@ -298,6 +368,10 @@ sub prep {
 # So instead:
   my $ftp = $self->login ;
 
+  
+  $self->Common(LocalDir => '.') unless
+      $self->GetCommon('LocalDir') ;
+
   if ($self->{Common}->{RemoteDir}) {
       $ftp->cwd($self->GetCommon('RemoteDir'))
   } else {
@@ -329,27 +403,28 @@ sub get {
   my $r;
 
   my $file;
+
   if ($self->GetCommon('LocalFile')) {
-      $file= $self->GetCommon('LocalFile');
+    $file= $self->GetCommon('LocalFile');
   } else {
-      $file=$self->GetCommon('RemoteFile');
+    $file=$self->GetCommon('RemoteFile');
   }
 	
   my $local_file = join '/', ($self->GetCommon('LocalDir'), $file);
 		
-#  warn "LF: $local_file ", "D: ", Dumper($self);
+  #  warn "LF: $local_file ", "D: ", Dumper($self);
 
 
   if ($r = $ftp->get($self->GetCommon('RemoteFile'), $local_file)) {
-      return $r;
+    return $r;
   } else { 
     warn sprintf 'download of %s to %s failed',
-	  $self->GetCommon('RemoteFile'), $self->GetCommon('LocalFile');
+	$self->GetCommon('RemoteFile'), $self->GetCommon('LocalFile');
     warn 
 	'here are the settings in your Net::FTP::Common object: %s',
-	Dumper($self);
+	    Dumper($self);
     return undef;
-}
+  }
   
 
 }
@@ -371,7 +446,7 @@ sub send {
 
   my $ftp = $self->prep(%cfg);
 
-#  warn "send_self", Dumper($self);
+  #  warn "send_self", Dumper($self);
 
   my %fa = $self->file_attr;
 
@@ -380,13 +455,14 @@ sub send {
       return;
   }
 
-#  warn "send_fa: ", Dumper(\%fa);
+  warn "send_fa: ", Dumper(\%fa) if $self->{Debug} ;
+
 
   my $lf = sprintf "%s/%s", $fa{LocalDir}, $fa{LocalFile};
   my $RF = $fa{RemoteFile} ? $fa{RemoteFile} : $fa{LocalFile};
   my $rf = sprintf "%s/%s", $fa{RemoteDir}, $RF;
 
-#  warn "[upload $lf as $rf]";
+  warn "[upload $lf as $rf]" if $self->{Debug} ;
 
   $ftp->put($lf, $RF) or 
       confess sprintf "upload of %s to %s failed", $lf, $rf;
@@ -426,10 +502,11 @@ Net::FTP::Common - simplify common usages of Net::FTP
      #
 
 
-     LocalFile => 'delete.zip'       # setup something for $ez->get
-     Host => 'ftp.fcc.gov',          # overwrite ftp.microsoft.com default
-     RemoteDir  => '/',                    # automatic CD on remote machine to RemoteDir
-     Type => 'A'                     # overwrite I (binary) TYPE default
+     LocalFile => 'delete.zip'   # setup something for $ez->get
+     Host => 'ftp.fcc.gov',      # overwrite ftp.microsoft.com default
+     LocalDir   => '/tmp',
+     RemoteDir  => '/',          # automatic CD on remote machine to RemoteDir
+     Type => 'A'                 # overwrite I (binary) TYPE default
      );
 
   # NOTE WELL!!! one constructor arg is  passed by reference, the 
@@ -642,6 +719,7 @@ example:
  my @dir =qw (/tmp /pub /gnu);
  map { @{$dir{$_}} = $ftp->ls(RemoteDir => $_ ) } @dir;
 
+
 =head2 %retval = $ez->dir (%override)
 
 B<this function returns a hash NOT an array>
@@ -739,6 +817,15 @@ Here is the results of the example from the the test suite (t/dir.t):
                        'perm' => 'drwxr-xr-x'
                      },
 
+=head2 $ez->delete (%override)
+
+This function logins into the remote machine, changes to C<RemoteDir> and then 
+issues C<$ftp->delete> on C<RemoteFile>
+
+In the C<samples/delete-file> directory of the distribution 
+exists files called 
+C<upload.pl> and C<download.pl> which together with C<Login.pm> will log into 
+a system and upload or delete the C<upfile>
 
 =head2 $ez->mkdir (%override)
 
@@ -762,6 +849,11 @@ file in a directory listing. This means a regex, not C<eq> match.
 
 =head2 $ez->get(%override)
 
+IMPORTANT: C<LocalDir> must be set when you create a Net::FTP::Common object 
+(i.e, when you call Net::FTP::Common->new) or your Net::FTP::Common will
+default C<LocalDir> to "." and warn you about it.
+
+
 
 uses the C<RemoteFile>, C<LocalFile>, and C<LocalDir> options of object internal 
 state 
@@ -821,6 +913,15 @@ AppConfig anyway, it rocks the house.
 
 net-ftp-common-subscribe@yahoogroups.com
 
+=head1 * A harmless warning
+
+When a Net::FTP::Common object is goes out of scope, the following warning 
+is thrown by Net::FTP: 
+
+  Not a GLOB reference at Net/FTP.pm line 147.
+
+This is a harmless warning that I should fix some day. 
+
 =back
 
 =head1 TODO
@@ -830,6 +931,10 @@ net-ftp-common-subscribe@yahoogroups.com
 
 =over 4
 
+=item * replace parsing in dir() with lwp's File::Listing::line()
+
+=item * adding a warning about any keys passed that are not recognised 
+
 =item * support resumeable downloads
 
 =back
@@ -881,6 +986,20 @@ http://perlmonks.org/index.pl?node_id=317408
 
 T. M. Brannon <tbone@cpan.org>
 
-dir() method contributed by Kevin Evans (kevin _! a t (* i n s i g ht dot-com
+=head2 Acknowledgements
+
+=over 4
+
+=item * Kevin Evans
+
+dir() method contributed by Kevin Evans (kevin  a t  i n s i g h t dot-com)
+
+=item * Matthew Browning (matthewb on perlmonks)
+
+pointed out a problem with the dir() regexp which then led to me 
+plagiarizing a healthy section of File::Listing::line() from the LWP
+distro.
+
+=back
 
 =cut
