@@ -6,18 +6,18 @@ our %netftp_cfg =
 our %common_cfg =    
     (
      User => 'anonymous',           # overwrite anonymous USER default
-     Host => 'ftp.k-r-nel.org',         # overwrite ftp.microsoft.com HOST default
+     Host => 'ftp.kernel.org',      # overwrite ftp.microsoft.com HOST default
      Pass => 'tbone@cpan.org',      # overwrite list@rebol.com PASS default
      RemoteDir  => '/pub',                   # overwrite slash DIR default
      Type => 'I'                    # (binary) TYPE default
      );
 
-our %usc_cfg =    
+our %dart_cfg =    
     (
      User => 'anonymous',           # overwrite anonymous USER default
-     Host => 'lnc.usc.edu',         # overwrite ftp.microsoft.com HOST default
+     Host => 'ftp.dartmouth.edu',   # overwrite ftp.microsoft.com HOST default
      Pass => 'tbone@cpan.org',      # overwrite list@rebol.com PASS default
-     RemoteDir  => '/pub',                   # overwrite slash DIR default
+     RemoteDir  => '/pub/software', # overwrite slash DIR default
      Type => 'I'                    # (binary) TYPE default
      );
 
